@@ -11,12 +11,11 @@
 
 #include <numeric>
 
-#include "eckit/filesystem/marsfs/MarsFSPath.h"
 #include "eckit/io/cluster/NodeInfo.h"
 #include "eckit/log/Log.h"
 
-#include "eckit/io/PartFileHandle.h"
 #include "eckit/exception/Exceptions.h"
+#include "eckit/io/PartFileHandle.h"
 
 #include "eckit/io/PooledHandle.h"
 
@@ -31,10 +30,13 @@ ClassSpec PartFileHandle::classSpec_ = {
 Reanimator<PartFileHandle> PartFileHandle::reanimator_;
 
 void PartFileHandle::print(std::ostream& s) const {
-    if (format(s) == Log::compactFormat)
+    if (format(s) == Log::compactFormat) {
         s << "PartFileHandle";
-    else
-        s << "PartFileHandle[path=" << path_ << ",offset=" << offset_ << ",length=" << length_ << ']';
+    }
+    else {
+        s << "PartFileHandle[path=" << path_ << ",offset=" << offset_ << ",length=" << length_
+          << ']';
+    }
 }
 
 void PartFileHandle::encode(Stream& s) const {
@@ -44,7 +46,8 @@ void PartFileHandle::encode(Stream& s) const {
     s << length_;
 }
 
-PartFileHandle::PartFileHandle(Stream& s) : DataHandle(s), pos_(0), index_(0) {
+PartFileHandle::PartFileHandle(Stream& s) :
+    DataHandle(s), pos_(0), index_(0) {
     s >> path_;
     s >> offset_;
     s >> length_;
@@ -53,24 +56,14 @@ PartFileHandle::PartFileHandle(Stream& s) : DataHandle(s), pos_(0), index_(0) {
 }
 
 PartFileHandle::PartFileHandle(const PathName& name, const OffsetList& offset, const LengthList& length) :
-    path_(name),
-    handle_(),
-    pos_(0),
-    index_(0),
-    offset_(offset),
-    length_(length) {
+    path_(name), handle_(), pos_(0), index_(0), offset_(offset), length_(length) {
     //    Log::info() << "PartFileHandle::PartFileHandle " << name << std::endl;
     ASSERT(offset_.size() == length_.size());
     compress(false);
 }
 
 PartFileHandle::PartFileHandle(const PathName& name, const Offset& offset, const Length& length) :
-    path_(name),
-    handle_(),
-    pos_(0),
-    index_(0),
-    offset_(1, offset),
-    length_(1, length) {}
+    path_(name), handle_(), pos_(0), index_(0), offset_(1, offset), length_(1, length) {}
 
 
 DataHandle* PartFileHandle::clone() const {
@@ -79,13 +72,13 @@ DataHandle* PartFileHandle::clone() const {
 
 
 bool PartFileHandle::compress(bool sorted) {
-    if (sorted)
+    if (sorted) {
         eckit::sort(offset_, length_);
+    }
     return eckit::compress(offset_, length_);
 }
 
-PartFileHandle::~PartFileHandle() {
-}
+PartFileHandle::~PartFileHandle() {}
 
 Length PartFileHandle::openForRead() {
     if (!handle_) {
@@ -110,12 +103,13 @@ long PartFileHandle::read1(char* buffer, long length) {
     ASSERT(handle_);
 
     // skip empty entries if any
-    while (index_ < offset_.size() && length_[index_] == Length(0))
+    while (index_ < offset_.size() && length_[index_] == Length(0)) {
         index_++;
+    }
 
-    if (index_ == offset_.size())
+    if (index_ == offset_.size()) {
         return 0;
-
+    }
 
     Length ll = (long long)offset_[index_] + Length(pos_);
     off_t pos = ll;
@@ -202,45 +196,55 @@ void PartFileHandle::restartReadFrom(const Offset& from) {
 
 Offset PartFileHandle::position() {
     long long position = 0;
-    for (int i = 0; i < index_; i++) {
+    for (Ordinal i = 0; i < index_; i++) {
         position += length_[i];
     }
     return position + Length(pos_);
 }
 
-Offset PartFileHandle::seek(const Offset& from) {
+Offset PartFileHandle::seek(const Offset& offset) {
     rewind();
-    long long len = from;
-    long long pos = 0;
+    const long long seekto = offset;
+    long long accumulated  = 0;
 
     for (index_ = 0; index_ < length_.size(); index_++) {
-        long long e = length_[index_];
-        if (len >= pos && len < pos + e) {
-            pos_ = len - pos;
-            return from;
+        long long len = length_[index_];
+        if (accumulated <= seekto && seekto < accumulated + len) {
+            pos_ = seekto - accumulated;
+            return offset;
         }
-        pos += e;
+        accumulated += len;
     }
-    return pos;
+    long long beyond = seekto - accumulated;
+    // check if seek went beyond EOF which is POSIX compliant, but we ASSERT so we find possible bugs
+    ASSERT(not beyond);
+    pos_ = 0;
+    return seekto;
 }
 
+bool PartFileHandle::canSeek() const {
+    return true;
+}
 
 bool PartFileHandle::merge(DataHandle* other) {
-    if (other->isEmpty())
+    if (other->isEmpty()) {
         return true;
+    }
 
     // Poor man's RTTI,
     // Does not support inheritance
 
-    if (!sameClass(*other))
+    if (!sameClass(*other)) {
         return false;
+    }
 
     // We should be safe to cast now....
 
     PartFileHandle* handle = dynamic_cast<PartFileHandle*>(other);
 
-    if (path_ != handle->path_)
+    if (path_ != handle->path_) {
         return false;
+    }
 
     ASSERT(handle->offset_.size() == handle->length_.size());
 
@@ -277,6 +281,10 @@ std::string PartFileHandle::title() const {
     return os.str();
 }
 
+std::string PartFileHandle::metricsTag() const {
+    return PathName::metricsTag(path_);
+}
+
 //----------------------------------------------------------------------------------------------------------------------
 
 }  // namespace eckit
