@@ -20,6 +20,8 @@
 #include "eckit/exception/Exceptions.h"
 #include "eckit/io/Buffer.h"
 #include "eckit/log/Log.h"
+#include "eckit/maths/Functions.h"
+#include "eckit/os/BackTrace.h"
 #include "eckit/serialisation/BadTag.h"
 
 namespace eckit {
@@ -61,7 +63,8 @@ static const char* tag_names[] = {"0",
 const int tag_count = sizeof(tag_names) / sizeof(tag_names[0]);
 
 
-Stream::Stream() : lastTag_(tag_zero), writeCount_(0) {}
+Stream::Stream() :
+    lastTag_(tag_zero), writeCount_(0) {}
 
 void Stream::print(std::ostream& s) const {
     s << name();
@@ -71,8 +74,9 @@ Stream::~Stream() {}
 
 void Stream::putBytes(const void* buf, long len) {
     writeCount_ += len;
-    if (write(buf, len) != len)
+    if (write(buf, len) != len) {
         throw WriteError(name());
+    }
 }
 
 std::ostream& operator<<(std::ostream& out, const Stream& s) {
@@ -81,8 +85,9 @@ std::ostream& operator<<(std::ostream& out, const Stream& s) {
 }
 
 void Stream::getBytes(void* buf, long len) {
-    if (read(buf, len) != len)
+    if (read(buf, len) != len) {
         throw ReadError(name());
+    }
 }
 
 
@@ -109,8 +114,9 @@ void Stream::putLong(unsigned long p) {
             unsigned short s = htons(p);
             putBytes(&s, sizeof(s));
         }
-        else
+        else {
             NOTIMP;
+        }
     }
     else {
         p = htonl(p);
@@ -125,26 +131,24 @@ unsigned long Stream::getLong() {
             getBytes(&n, sizeof(n));
             return ntohl(n);
         }
-        else if (sizeof(unsigned short) == 4) {
+        if (sizeof(unsigned short) == 4) {
             unsigned short s;
             getBytes(&s, sizeof(s));
             return ntohs(s);
         }
-        else
-            NOTIMP;
-    }
-    else {
-        long p;
-        getBytes(&p, sizeof(p));
-        return ntohl(p);
+        NOTIMP;
     }
+
+    long p;
+    getBytes(&p, sizeof(p));
+    return ntohl(p);
 }
 
 std::ostream& operator<<(std::ostream& s, Stream::tag t) {
-    if (t >= 0 && t < tag_count)
+    if (t >= 0 && t < tag_count) {
         return s << '\'' << tag_names[t] << '\'';
-    else
-        return s << '\'' << long(t) << '\'';
+    }
+    return s << '\'' << long(t) << '\'';
 }
 
 void Stream::badTag(Stream::tag need, Stream::tag got) {
@@ -155,13 +159,15 @@ void Stream::badTag(Stream::tag need, Stream::tag got) {
     os << ". Expecting a " << need << ", got a " << got;
 
     Log::error() << os.str() << std::endl;
+    Log::error() << BackTrace::dump() << std::endl;
 
     if (got == tag_string) {
         long length = getLong();
         std::string s;
         s.resize(length);
-        for (long i = 0; i < length; i++)
+        for (long i = 0; i < length; i++) {
             s[i] = getChar();
+        }
         Log::error() << "String is " << s << std::endl;
     }
 
@@ -184,8 +190,9 @@ Stream::tag Stream::nextTag() {
         return tag_eof;
     }
 
-    if (len == EOF)
+    if (len == EOF) {
         throw ShortFile(name());
+    }
 
     tag t = static_cast<tag>(c);
     //  Log::debug() << "Next tag " << t << std::endl;
@@ -197,8 +204,9 @@ Stream::tag Stream::readTag(Stream::tag need) {
 
     // Skip any end-of-object lingering
 
-    while ((t = nextTag()) == tag_end_obj)
+    while ((t = nextTag()) == tag_end_obj) {
         ;
+    }
 
     if (t == tag_exception) {
         std::string s;
@@ -206,9 +214,9 @@ Stream::tag Stream::readTag(Stream::tag need) {
         throw RemoteException(s, name());
     }
 
-    if (need != t)
+    if (need != t) {
         badTag(need, t);
-
+    }
 
     return t;
 }
@@ -369,15 +377,10 @@ Stream& Stream::operator<<(const char* x) {
 Stream& Stream::operator<<(const std::string& x) {
     T("w std::string", x);
     writeTag(tag_string);
-    long len = x.length();
+    const long len = x.length();
     putLong(len);
-
-    char buf[len];
     assert(sizeof(unsigned char) == 1);
-    for (long i = 0; i < len; i++)
-        buf[i] = x[i];
-
-    putBytes(buf, len);
+    putBytes(x.c_str(), len);
     return *this;
 }
 
@@ -627,14 +630,14 @@ Stream& Stream::operator>>(double& x) {
 
 Stream& Stream::operator>>(std::string& s) {
     readTag(tag_string);
-    long length = getLong();
-    char buf[length];
+    const long length = getLong();
+
+    const long sz = eckit::round(length + 1, 8);  // some padding to avoid zero-length buffer
+    char buf[sz];
     getBytes(buf, length);
 
     s.resize(length);
-
-    for (long i = 0; i < length; i++)
-        s[i] = buf[i];
+    s.assign(buf, length);
 
     T("r std::string", s);
     return *this;
@@ -642,26 +645,63 @@ Stream& Stream::operator>>(std::string& s) {
 
 bool Stream::next(std::string& s) {
     tag t = nextTag();
-    if (t == tag_eof)
+    if (t == tag_eof) {
         return false;
+    }
 
-    if (t != tag_string)
+    if (t != tag_string) {
         badTag(tag_string, t);
+    }
 
     long length = getLong();
     char buf[length];
     getBytes(buf, length);
 
     s.resize(length);
-
-    for (long i = 0; i < length; i++)
-        s[i] = buf[i];
+    s.assign(buf, length);
 
     T("r std::string", s);
 
     return true;
 }
 
+bool Stream::next(int& x) {
+
+    tag t = nextTag();
+    if (t == tag_eof) {
+        return false;
+    }
+
+    if (t != tag_int) {
+        badTag(tag_int, t);
+    }
+
+    union {
+        uint32_t u;
+        int32_t s;
+    } u;
+
+    u.u = getLong();
+    x   = u.s;
+    T("r int", x);
+    return true;
+}
+
+
+bool Stream::next(bool& b) {
+
+    int x = 0;
+    if (!next(x)) {
+        return false;
+    }
+
+    b = x;
+    T("r bool", b);
+
+    return true;
+}
+
+
 void Stream::startObject() {
     T("w start", 0);
     writeTag(tag_start_obj);
@@ -678,8 +718,9 @@ bool Stream::endObjectFound() {
 }
 
 void Stream::skipEndObject() {
-    if (endObjectFound())
+    if (endObjectFound()) {
         lastTag_ = tag_zero;
+    }
 }
 
 #if 0
@@ -730,14 +771,17 @@ bool Stream::next() {
     for (;;) {
         tag t = nextTag();
 
-        if (t == tag_start_obj)
+        if (t == tag_start_obj) {
             return true;
+        }
 
-        if (t == tag_eof)
+        if (t == tag_eof) {
             return false;
+        }
 
-        if (t != tag_end_obj)
+        if (t != tag_end_obj) {
             badTag(tag_start_obj, t);
+        }
     }
 }
 
@@ -758,7 +802,8 @@ class StreamDecoder : public Stream {
     virtual std::string name() const { return "StreamDecoder"; }
 
 public:
-    StreamDecoder(const char* buffer) : buffer_(buffer), pos_(0), len_(0) {}
+    StreamDecoder(const char* buffer) :
+        buffer_(buffer), pos_(0), len_(0) {}
     size_t len() const { return len_; }
 };
 
